import { RoleResolvable, TextChannelResolvable } from "discord.js";

import { ModeratorGuild, ModeratorGuildMember } from "./ModeratorData";

import { MuteType, PunishmentType } from "./ModeratorEnums";

export interface CreateMuteOptions {
    type: MuteType;
    time?: number;
    reason?: string;
    moderator?: string;
    
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
    channel: TextChannelResolvable;
}

export interface DeleteMuteOptions {
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
}

export interface SetMuteRoleOptions {
    role: RoleResolvable;
    guild: ModeratorGuild;
}

export interface CreateWarnOptions {
    reason?: string;
    moderator?: string;

    user: ModeratorGuildMember;
    guild: ModeratorGuild;
    channel: TextChannelResolvable;
}

export interface DeleteWarnOptions {
    id: string;
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
}

export interface ClearOptions {
    count?: number;
    channel: TextChannelResolvable;
}

export interface PunishOptions {
    type: PunishmentType;
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
    channel: TextChannelResolvable;

    time?: number;
    reason?: string;
    moderator?: string;
}

export interface UnbanOptions {
    user: string;
    guild: ModeratorGuild;
}

export interface BanOptions {
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
    reason?: string;
}

export interface KickOptions {
    user: ModeratorGuildMember;
    guild: ModeratorGuild;
    reason?: string;
}

export interface ListOptions {
    user?: string;
    guild: string;
}

export interface FetchOptions {
    id: string;
    user?: string;
    guild?: string;
}

export type Options<
    T extends
        CreateMuteOptions |
        DeleteMuteOptions |
        SetMuteRoleOptions |
        CreateWarnOptions |
        DeleteWarnOptions |
        ClearOptions |
        PunishOptions |
        UnbanOptions |
        BanOptions |
        KickOptions |
        ListOptions |
        FetchOptions
> = T;